Crate enum_helper_derive

Crate enum_helper_derive 

Procedural macro implementations for enum-helper.

You normally depend on enum-helper (which re-exports these macros) rather than using this crate directly.

Derive Macros

EnumAll
Derive the EnumAll trait and generate an array of all variants.
EnumKind
Derive the EnumKind trait and generate a unit kind enum from a data-carrying enum.
EnumStr
Derive the EnumStr trait to convert between a unit enum and string.